==> am_mod_lbr_0_3.zip: am_mod_lbr_0_3/components/lbr/template/barnraiser_01/page_edit.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<script language="JavaScript" src="<?php echo $template_path_core;?>/js/imageHandling.js" type="text/javascript"></script>

<form action="index.php?amn=lbr_page_edit" method="post" name="frm" id="id_frm">
<input type="hidden" name="page_id" value="<?php if(isset($page['page_id'])) { echo $page['page_id'];}?>" />
<input type="hidden" name="set_id" value="<?php if(isset($page['set_id'])) { echo $page['set_id'];}?>" />
<input type="hidden" name="page_name" value="<?php if(isset($page['page_name'])) { echo $page['page_name'];}?>" />

<?php
if (isset($display) && $display == "page_edit") {
?>
<div class="col_main">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_page'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
				<?php if (isset($page['page_name'])) { echo $page['page_name'];}?>
				
				<p>
					<label for="id_page_title"><?php echo $lang['txt_title'];?></label>
					<input id="id_page_title" class="input" type="text" name="page_title" size="24" value="<?php if (isset($page['page_title'])) { echo $page['page_title'];}?>" />
					&nbsp;<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
					<br />
				</p>
				
				<p>
					<label for="id_page_synopsis"><?php echo $lang['txt_synopsis'];?></label>
					<textarea id="id_page_synopsis" name="page_synopsis" cols="22" rows="2"><?php if (isset($page['page_synopsis'])) { echo $page['page_synopsis'];}?></textarea>
					<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('help.php?help=library_item#invite');" />
					<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
					<br />
				</p>
				
				<?php
				if (isset($images)) {
				?>
				<table cellspacing="0" cellpadding="2" border="0" width="100%">
					<tr>
						<td valign="top">
							<label for="frm_file" style="width:105px;"><?php echo $lang['txt_image']; ?></label><br />
						</td>
						<td valign="top" width="100%">
							<select style="width:150px;" id="id_file_id" size=3 name="file_id" onChange='javascript:setimg(this)'>
								<option value="0" selected="selected"><?php echo $lang['txt_none'];?></option>
								<?php
								$img_divs = "";
								foreach($images as $key => $i):
								$display_state = "none";
								$selected = "";
								if (isset($page['file_id']) && $page['file_id'] == $i['file_id']) {
									$selected = "selected=\"selected\"";
									$display_state = "block";
								}
								?>
								<option value="<?php echo $i['file_id'];?>" <?php echo $selected;?>><?php echo $i['file_save_name'];?></option>
								<?php
								$img_divs .= "<div style=\"display:" . $display_state . ";\" id=img" . $i['file_id'] . "><img src=\"get_file.php?file=" . $i['file_md5_name_view'] . "&amp;type=" . $i['type'] . "&amp;directory=" . $i['directory'] . "\" border=\"0\" class=\"picture\" /></div>";
								endforeach;
								?>
							</select>
						</td>
						<td valign="top" align="right">
							<?php echo $img_divs;?>
						</td>	
					</tr>
				</table>
				<?php }?>
				
				
				<?php
				if (isset($library_config['resource']['page'])) {
				?>
				
				<hr />
				
				<p>
					<b><?php echo $lang['hdr_permissions'];?></b><br />
				</p>
		
				<?php
				foreach($library_config['resource']['page'] as $rekey => $re):
				?>
				
				<?php
				$checked = "";
				if (isset($page)) {
					if ($page['page_permission'] & $library_config['resource']['page'][$rekey]) {
						$checked = "checked=\"checked\"";
					}
				}
				?>
				<p>
					<input type="checkbox" name="permission[page][<?php echo $re;?>]" value="<?php echo $re;?>" <?php echo $checked;?> />&nbsp;
					<?php echo $lang['resource'][$module_prefix]['page'][$re];?><br />
				</p>
				<?php
				endforeach;
				?>		
				<?php }?>
		
				<hr />
							
				<p align="right">
					<?php
					if (isset($allow_spellcheck)) {
					?>
					<input type="button" class="input_submit" value="<?php echo $lang['sub_check_spelling'];?>" onClick="openSpellChecker();" />
					<?php }?>
					
					<?php
					if (!empty($page['page_id'])) {
					?>
					<input type="submit" name="update_page" id="id_sub_update" class="input_submit" value="<?php echo $lang['sub_update'];?>" />
					<?php
					}
					else {
					?>
					<input type="submit" name="insert_page" id="id_sub_insert" class="input_submit" value="<?php echo $lang['sub_insert'];?>" />
					<?php }?>
					<br />
				</p>
			</div>
		</div>
	</div>
</div>


<div class="col_side">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_revisions'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($revisions)) {
				?>
				<p align="right">
					<a href="index.php?amn=lbr_revision_edit&amp;page_id=<?php echo $page['page_id'];?>&amp;revision_id=<?php echo $page['current_revision_id'];?>"><?php echo $lang['href_edit_current_revision'];?></a><br />
				</p>
				
				<table cellspacing="0" cellpadding="0" border="0" width="100%">
					<?php
					foreach ($revisions as $key => $i):
					?>
					<tr>
						<td valign="top">
							<a href=""><?php echo $this->date->formatDate($i['revision_create_datetime'],1);?></a><br />
						</td>
						<td valign="top" align="right">
							<?php
							$checked = "";
							
							if ($i['revision_id'] == $page['current_revision_id']) {
								$checked = " checked=\"checked\"";
							}
							?>			
						
							<input type="radio" name="current_revision_id" value="<?php echo $i['revision_id'];?>" <?php echo $checked;?> /><br />
						</td>
					</tr>				
					<?php
					endforeach;
					?>
				</table>
				
				<p align="right">
					<input type="submit" name="set_current_revision_id" id="id_sub_update_current_revision" class="input_submit" value="<?php echo $lang['sub_update_current_revision'];?>" />
					<br />
				</p>
				<?php }?>
			</div>
		</div>
	</div>
</div>

<?php
}
else { // we create a page
?>

<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_create_page'];?><br />
	</div>
		
	<div class="box_mid">
		<div class="content">
			<table cellspacing="0" cellpadding="0" border="0">
				<tr>
					<td valign="top" width="50%">
						<p>
							<label for="id_page_title"><?php echo $lang['txt_title'];?></label>
							<input id="id_page_title" class="input" type="text" name="page_title" size="24" value="<?php if (isset($page['page_title'])) { echo $page['page_title'];}?>" />
							&nbsp;<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
							<br />
						</p>
						
						<p>
							<label for="id_page_synopsis"><?php echo $lang['txt_synopsis'];?></label>
							<textarea id="id_page_synopsis" name="page_synopsis" cols="22" rows="2"><?php if (isset($page['page_synopsis'])) { echo $page['page_synopsis'];}?></textarea>
							<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('help.php?help=library_item#invite');" />
							<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
							<br />
						</p>
						
					</td>
					<td>
						<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" width="20" /><br />
					</td>
					<td valign="top" width="50%">
			
						<?php
						if (isset($images)) {
						?>
						<table cellspacing="0" cellpadding="2" border="0" width="100%">
							<tr>
								<td valign="top">
									<label for="frm_file" style="width:105px;"><?php echo $lang['txt_image']; ?></label><br />
								</td>
								<td valign="top" width="100%">
									<select style="width:150px;" id="id_file_id" size=3 name="file_id" onChange='javascript:setimg(this)'>
										<option value="0" selected="selected"><?php echo $lang['txt_none'];?></option>
										<?php
										$img_divs = "";
										foreach($images as $key => $i):
										$display_state = "none";
										$selected = "";
										if (isset($page['file_id']) && $page['file_id'] == $i['file_id']) {
											$selected = "selected=\"selected\"";
											$display_state = "block";
										}
										?>
										<option value="<?php echo $i['file_id'];?>" <?php echo $selected;?>><?php echo $i['file_save_name'];?></option>
										<?php
										$img_divs .= "<div style=\"display:" . $display_state . ";\" id=img" . $i['file_id'] . "><img src=\"get_file.php?file=" . $i['file_md5_name_view'] . "&amp;type=" . $i['type'] . "&amp;directory=" . $i['directory'] . "\" border=\"0\" class=\"picture\" /></div>";
										endforeach;
										?>
									</select>
								</td>
								<td valign="top" align="right">
									<?php echo $img_divs;?>
								</td>	
							</tr>
						</table>
						<?php }?>
			
			
						<?php
						if (isset($library_config['resource']['page'])) {
						?>
				
						<?php
						foreach($library_config['resource']['page'] as $rekey => $re):
						?>
						
						<?php
						$checked = "";
						if (isset($page)) {
							if ($page['page_permission'] & $library_config['resource']['page'][$rekey]) {
								$checked = "checked=\"checked\"";
							}
						}
						?>
						<p>
							<input type="checkbox" name="permission[page][<?php echo $re;?>]" value="<?php echo $re;?>" <?php echo $checked;?> />&nbsp;
							<?php echo $lang['resource'][$module_prefix]['page'][$re];?><br />
						</p>
						<?php
						endforeach;
						?>		
						<?php }?>
					</td>
				</tr>
			</table>
	
			<hr />
			
			<p>
				<label for="id_revision_body"><?php echo $lang['txt_revision_body'];?></label>
				<textarea id="id_revision_body" name="revision_body" cols="62" rows="4"><?php if (isset($revision['revision_body'])) { echo $revision['revision_body'];}?></textarea>
				<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('components/core/help.php?help=grp_group#invite');" />
				<br />			
			</p>

			<hr />
						
			<p align="right">
				<?php
				if (isset($allow_spellcheck)) {
				?>
				<input type="button" class="input_submit" value="<?php echo $lang['sub_check_spelling'];?>" onClick="openSpellChecker();" />
				<?php }?>
				
				<input type="submit" name="insert_page" id="id_sub_insert" class="input_submit" value="<?php echo $lang['sub_insert'];?>" />
				<br />
			</p>
		</div>
	</div>
</div>
<?php }?>
</form>

==> am_mod_lbr_0_5.zip: am_mod_lbr_0_5/components/lbr/template/barnraiser_01/page_edit.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<script language="JavaScript" src="<?php echo $template_path_core;?>/js/imageHandling.js" type="text/javascript"></script>

<form action="index.php?amn=lbr_page_edit" method="post" name="frm" id="id_frm">
<input type="hidden" name="page_id" value="<?php if(isset($page['page_id'])) { echo $page['page_id'];}?>" />
<input type="hidden" name="set_id" value="<?php if(isset($page['set_id'])) { echo $page['set_id'];}?>" />
<input type="hidden" name="page_name" value="<?php if(isset($page['page_name'])) { echo $page['page_name'];}?>" />

<?php
if (isset($display) && $display == "page_edit") {
?>
<div class="col_main">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_page'];?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				<?php if (isset($page['page_name'])) { echo $page['page_name'];}?>
				
				<p>
					<label for="id_page_title"><?php echo $lang['txt_title'];?></label>
					<input id="id_page_title" class="input" type="text" name="page_title" size="24" value="<?php if (isset($page['page_title'])) { echo $page['page_title'];}?>" />
					&nbsp;<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
					<br />
				</p>
				
				<p>
					<label for="id_page_synopsis"><?php echo $lang['txt_synopsis'];?></label>
					<textarea id="id_page_synopsis" name="page_synopsis" cols="22" rows="2"><?php if (isset($page['page_synopsis'])) { echo $page['page_synopsis'];}?></textarea>
					<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('help.php?help=library_item#invite');" />
					<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
					<br />
				</p>
				
				<?php
				if (isset($images)) {
				?>
				<table cellspacing="0" cellpadding="2" border="0" width="100%">
					<tr>
						<td valign="top">
							<label for="frm_file" style="width:105px;"><?php echo $lang['txt_image']; ?></label><br />
						</td>
						<td valign="top" width="100%">
							<select style="width:150px;" id="id_file_id" size=3 name="file_id" onChange='javascript:setimg(this)'>
								<option value="0" selected="selected"><?php echo $lang['txt_none'];?></option>
								<?php
								$img_divs = "";
								foreach($images as $key => $i):
								$display_state = "none";
								$selected = "";
								if (isset($page['file_id']) && $page['file_id'] == $i['file_id']) {
									$selected = "selected=\"selected\"";
									$display_state = "block";
								}
								?>
								<option value="<?php echo $i['file_id'];?>" <?php echo $selected;?>><?php echo $i['file_save_name'];?></option>
								<?php
								$img_divs .= "<div style=\"display:" . $display_state . ";\" id=img" . $i['file_id'] . "><img src=\"get_file.php?file=" . $i['file_md5_name_view'] . "&amp;type=" . $i['type'] . "&amp;directory=" . $i['directory'] . "\" border=\"0\" class=\"picture\" /></div>";
								endforeach;
								?>
							</select>
						</td>
						<td valign="top" align="right">
							<?php echo $img_divs;?>
						</td>	
					</tr>
				</table>
				<?php }?>
				
				
				<?php
				if (isset($library_config['resource']['page'])) {
				?>
				
				<hr />
				
				<p>
					<b><?php echo $lang['hdr_permissions'];?></b><br />
				</p>
		
				<?php
				foreach($library_config['resource']['page'] as $rekey => $re):
				?>
				
				<?php
				$checked = "";
				if (isset($page)) {
					if ($page['page_permission'] & $library_config['resource']['page'][$rekey]) {
						$checked = "checked=\"checked\"";
					}
				}
				?>
				<p>
					<input type="checkbox" name="permission[page][<?php echo $re;?>]" value="<?php echo $re;?>" <?php echo $checked;?> />&nbsp;
					<?php echo $lang['resource'][$module_prefix]['page'][$re];?><br />
				</p>
				<?php
				endforeach;
				?>
				<?php }?>
		
				<hr />
				
				<p align="right">
					<?php
					if (isset($allow_spellcheck)) {
					?>
					<input type="button" class="input_submit" value="<?php echo $lang['sub_check_spelling'];?>" onClick="openSpellChecker();" />
					<?php }?>
					
					<?php
					if (!empty($page['page_id'])) {
					?>
					<input type="submit" name="update_page" id="id_sub_update" class="input_submit" value="<?php echo $lang['sub_update'];?>" />
					<?php
					}
					else {
					?>
					<input type="submit" name="insert_page" id="id_sub_insert" class="input_submit" value="<?php echo $lang['sub_insert'];?>" />
					<?php }?>
					<br />
				</p>
			</div>
		</div>
	</div>
</div>


<div class="col_side">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_revisions'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($revisions)) {
				?>
				<p align="right">
					<a href="index.php?amn=lbr_revision_edit&amp;page_id=<?php echo $page['page_id'];?>&amp;revision_id=<?php echo $page['current_revision_id'];?>"><?php echo $lang['href_edit_current_revision'];?></a><br />
				</p>
				
				<table cellspacing="0" cellpadding="0" border="0" width="100%">
					<?php
					foreach ($revisions as $key => $i):
					?>
					<tr>
						<td valign="top">
							<a href=""><?php echo $this->date->formatDate($i['revision_create_datetime'],1);?></a><br />
						</td>
						<td valign="top" align="right">
							<?php
							$checked = "";
							
							if ($i['revision_id'] == $page['current_revision_id']) {
								$checked = " checked=\"checked\"";
							}
							?>			
						
							<input type="radio" name="current_revision_id" value="<?php echo $i['revision_id'];?>" <?php echo $checked;?> /><br />
						</td>
					</tr>				
					<?php
					endforeach;
					?>
				</table>
				
				<p align="right">
					<input type="submit" name="set_current_revision_id" id="id_sub_update_current_revision" class="input_submit" value="<?php echo $lang['sub_update_current_revision'];?>" />
					<br />
				</p>
				<?php }?>
			</div>
		</div>
	</div>
</div>

<?php
}
else { // we create a page
?>

<div class="box">
	<div class="box_top">
		<div class="content">
			<h1><?php echo $lang['hdr_create_page'];?></h1>
		</div>
	</div>
		
	<div class="box_mid">
		<div class="content">
			<table cellspacing="0" cellpadding="0" border="0">
				<tr>
					<td valign="top" width="50%">
						<p>
							<label for="id_page_title"><?php echo $lang['txt_title'];?></label>
							<input id="id_page_title" class="input" type="text" name="page_title" size="24" value="<?php if (isset($page['page_title'])) { echo $page['page_title'];}?>" />
							&nbsp;<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
							<br />
						</p>
						
						<p>
							<label for="id_page_synopsis"><?php echo $lang['txt_synopsis'];?></label>
							<textarea id="id_page_synopsis" name="page_synopsis" cols="22" rows="2"><?php if (isset($page['page_synopsis'])) { echo $page['page_synopsis'];}?></textarea>
							<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('help.php?help=library_item#invite');" />
							<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
							<br />
						</p>
						
					</td>
					<td>
						<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" width="20" /><br />
					</td>
					<td valign="top" width="50%">
			
						<?php
						if (isset($images)) {
						?>
						<table cellspacing="0" cellpadding="2" border="0" width="100%">
							<tr>
								<td valign="top">
									<label for="frm_file" style="width:105px;"><?php echo $lang['txt_image']; ?></label><br />
								</td>
								<td valign="top" width="100%">
									<select style="width:150px;" id="id_file_id" size=3 name="file_id" onChange='javascript:setimg(this)'>
										<option value="0" selected="selected"><?php echo $lang['txt_none'];?></option>
										<?php
										$img_divs = "";
										foreach($images as $key => $i):
										$display_state = "none";
										$selected = "";
										if (isset($page['file_id']) && $page['file_id'] == $i['file_id']) {
											$selected = "selected=\"selected\"";
											$display_state = "block";
										}
										?>
										<option value="<?php echo $i['file_id'];?>" <?php echo $selected;?>><?php echo $i['file_save_name'];?></option>
										<?php
										$img_divs .= "<div style=\"display:" . $display_state . ";\" id=img" . $i['file_id'] . "><img src=\"get_file.php?file=" . $i['file_md5_name_view'] . "&amp;type=" . $i['type'] . "&amp;directory=" . $i['directory'] . "\" border=\"0\" class=\"picture\" /></div>";
										endforeach;
										?>
									</select>
								</td>
								<td valign="top" align="right">
									<?php echo $img_divs;?>
								</td>	
							</tr>
						</table>
						<?php }?>
			
			
						<?php
						if (isset($library_config['resource']['page'])) {
						?>
				
						<?php
						foreach($library_config['resource']['page'] as $rekey => $re):
						?>
						
						<?php
						$checked = "";
						if (isset($page)) {
							if ($page['page_permission'] & $library_config['resource']['page'][$rekey]) {
								$checked = "checked=\"checked\"";
							}
						}
						?>
						<p>
							<input type="checkbox" name="permission[page][<?php echo $re;?>]" value="<?php echo $re;?>" <?php echo $checked;?> />&nbsp;
							<?php echo $lang['resource'][$module_prefix]['page'][$re];?><br />
						</p>
						<?php
						endforeach;
						?>		
						<?php }?>
					</td>
				</tr>
			</table>
	
			<hr />
			
			<p>
				<label for="id_revision_body"><?php echo $lang['txt_revision_body'];?></label>
				<textarea id="id_revision_body" name="revision_body" cols="62" rows="4"><?php if (isset($revision['revision_body'])) { echo $revision['revision_body'];}?></textarea>
				<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('components/core/help.php?help=grp_group#invite');" />
				<br />
			</p>

			<hr />
			
			<p align="right">
				<?php
				if (isset($allow_spellcheck)) {
				?>
				<input type="button" class="input_submit" value="<?php echo $lang['sub_check_spelling'];?>" onClick="openSpellChecker();" />
				<?php }?>
				
				<input type="submit" name="insert_page" id="id_sub_insert" class="input_submit" value="<?php echo $lang['sub_insert'];?>" />
				<br />
			</p>
		</div>
	</div>
</div>
<?php }?>
</form>
